@@ -653,7 +653,9 @@ cal_home_plugin_init(CalHomePlugin *desktop_plugin)
   desktop_plugin->update_view = TRUE;
   desktop_plugin->update_if_visible = FALSE;
   desktop_plugin->has_24_time_format = cal_24_time_format();
+  desktop_plugin->show_all_recurrences = TRUE;
   desktop_plugin->show_age = FALSE;
+  desktop_plugin->visible_entry_mode = VISIBLE_ENTRY_EVENT;
   GtkWidget *contents = build_ui(desktop_plugin);
 
   gtk_window_set_default_size (GTK_WINDOW (desktop_plugin), CAL_WIDGET_WIDTH, 252);
