@@ -54,6 +54,13 @@ enum CalTimePeriod
   CAL_TIME_PERIOD_12MONTH
 };
 
+enum VisibleEntryMode
+{
+  VISIBLE_ENTRY_EVENT = 0,
+  VISIBLE_ENTRY_TASK,
+  VISIBLE_ENTRY_EVENT_AND_TASK
+};
+
 struct _CalHomePlugin
 {
   HDHomePluginItem hitem;
@@ -74,11 +81,13 @@ struct _CalHomePlugin
   gboolean update_if_visible;
   struct tm date_today;
   gboolean update_view;
+  gboolean show_all_recurrences;
   gint cal_row_count;
   gint today_events;
   time_t time_to_update;
   gint press_time;
   CalTimePeriod cal_time_period;
+  VisibleEntryMode visible_entry_mode;
   GtkListStore* event_list;
   GtkWidget* day_label;
   GtkWidget* month_label;
